Stan Math Library: stan/math/rev/core/dv_vari.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

dv_vari.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_CORE_DV_VARI_HPP
2 #define STAN_MATH_REV_CORE_DV_VARI_HPP
3
4 #include <stan/math/rev/core/vari.hpp>
5
6 namespace stan {
7 namespace math {
8
9 class op_dv_vari : public vari {
10 protected:
11 double ad_;
12 vari* bvi_;
13 public:
14 op_dv_vari(double f, double a, vari* bvi) :
15 vari(f),
16 ad_(a),
17 bvi_(bvi) {
18 }
19 };
20
21 }
22 }
23 #endif
stan::math::op_dv_vari
Definition: dv_vari.hpp:9
vari.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::vari
The variable implementation base class.
Definition: vari.hpp:30
stan::math::op_dv_vari::ad_
double ad_
Definition: dv_vari.hpp:11
stan::math::op_dv_vari::op_dv_vari
op_dv_vari(double f, double a, vari *bvi)
Definition: dv_vari.hpp:14
stan::math::op_dv_vari::bvi_
vari * bvi_
Definition: dv_vari.hpp:12

[ Stan Home Page ] © 2011–2016, Stan Development Team.